@@ -61,7 +61,7 @@ sub index {
         'US::SendGrid', 'US::Verizon', 'RU::MailRu', 'RU::Yandex', 'DE::GMX', 
         'US::Bigfoot', 'US::Facebook', 'US::Zoho', 'DE::EinsUndEins',
         'UK::MessageLabs', 'JP::EZweb', 'JP::KDDI', 'JP::Biglobe',
-        'US::ReceivingSES',
+        'US::ReceivingSES', 'US::AmazonWorkMail', 'US::Office365',
     ];
     return $index;
 }
