@@ -24,9 +24,7 @@ my $Re1 = {
 };
 
 my $ReFailure = {
-    #'notaccept' => [
-    #    qr/The following recipients did not receive this message:/,
-    #],
+    #'notaccept' => [ qr/The following recipients did not receive this message:/ ],
     'mailboxfull' => [
         qr/The user[(]s[)] account is temporarily over quota/,
     ],
@@ -82,13 +80,12 @@ sub scan {
     #
     $match++ if $mhead->{'from'}     =~ $Re0->{'from'};
     $match++ if $mhead->{'subject'}  =~ $Re0->{'subject'};
-    $match++ if $mhead->{'received'} =~ $Re0->{'received'};
+    $match++ if grep { $_ =~ $Re0->{'received'} } @{ $mhead->{'received'} };
     if( defined $mhead->{'message-id'} ) {
         $match++ if $mhead->{'message-id'} =~ $Re0->{'message-id'};
     }
     return undef if $match < 2;
 
-    require Sisimai::MIME;
     require Sisimai::String;
     require Sisimai::Address;
 
@@ -101,11 +98,17 @@ sub scan {
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $v = undef;
 
-    my $rxboundary = Sisimai::MIME->boundary( $mhead->{'content-type'}, 1 );
-    my @rxmessages = ();
-
-    $Re1->{'boundary'} = qr|\A$rxboundary\z| if length $rxboundary;
-    map { push @rxmessages, @{ $ReFailure->{ $_ } } } ( keys %$ReFailure );
+    if( $mhead->{'content-type'} ) {
+        # Get the boundary string and set regular expression for matching with
+        # the boundary string.
+        require Sisimai::MIME;
+        my $b0 = Sisimai::MIME->boundary( $mhead->{'content-type'}, 1 );
+        if( length $b0 ) {
+            # Convert to regular expression
+            $Re1->{'boundary'} = Sisimai::String->to_regexp( $b0 );
+        }
+    }
+    my @rxmessages = (); map { push @rxmessages, @{ $ReFailure->{ $_ } } } ( keys %$ReFailure );
 
     for my $e ( @hasdivided ) {
         # Read each line between $Re1->{'begin'} and $Re1->{'rfc822'}.
@@ -149,21 +152,23 @@ sub scan {
             next unless $readcursor & $Indicators->{'deliverystatus'};
             next unless length $e;
 
+            # The user(s) account is disabled.
+            #
+            # <***@ezweb.ne.jp>: 550 user unknown (in reply to RCPT TO command)
+            # 
+            #  -- OR --
+            # Each of the following recipients was rejected by a remote
+            # mail server.
+            #
+            #    Recipient: <******@ezweb.ne.jp>
+            #    >>> RCPT TO:<******@ezweb.ne.jp>
+            #    <<< 550 <******@ezweb.ne.jp>: User unknown
             $v = $dscontents->[ -1 ];
+
             if( $e =~ m/\A[<]([^ ]+[@][^ ]+)[>]\z/ ||
                 $e =~ m/\A[<]([^ ]+[@][^ ]+)[>]:?(.*)\z/ ||
                 $e =~ m/\A[ \t]+Recipient: [<]([^ ]+[@][^ ]+)[>]/ ) {
-                # The user(s) account is disabled.
-                #
-                # <***@ezweb.ne.jp>: 550 user unknown (in reply to RCPT TO command)
-                # 
-                #  -- OR --
-                # Each of the following recipients was rejected by a remote
-                # mail server.
-                #
-                #    Recipient: <******@ezweb.ne.jp>
-                #    >>> RCPT TO:<******@ezweb.ne.jp>
-                #    <<< 550 <******@ezweb.ne.jp>: User unknown
+
                 if( length $v->{'recipient'} ) {
                     # There are multiple recipient addresses in the message body.
                     push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
@@ -175,6 +180,7 @@ sub scan {
                     $v->{'recipient'} = $r;
                     $recipients++;
                 }
+
             } elsif( $e =~ m/\A[Ss]tatus:[ ]*(\d[.]\d+[.]\d+)/ ) {
                 # Status: 5.1.1
                 # Status:5.2.0
@@ -217,12 +223,11 @@ sub scan {
     require Sisimai::SMTP::Status;
 
     for my $e ( @$dscontents ) {
-
         if( scalar @{ $mhead->{'received'} } ) {
             # Get localhost and remote host name from Received header.
-            my $r = $mhead->{'received'};
-            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r->[0] ) };
-            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r->[-1] ) };
+            my $r0 = $mhead->{'received'};
+            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r0->[0] ) };
+            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r0->[-1] ) };
         }
 
         if( exists $e->{'alterrors'} && length $e->{'alterrors'} ) {
@@ -320,7 +325,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
