@@ -7,7 +7,15 @@ use warnings;
 # Based on Sisimai::MTA::Exim
 my $Re0 = {
     'from'      => qr/[<]?mailer-daemon[@].*mail[.]ru[>]?/i,
-    'subject'   => qr/Mail failure[.]\z/,
+    'subject'   => qr{(?:
+         Mail[ ]delivery[ ]failed(:[ ]returning[ ]message[ ]to[ ]sender)?
+        |Warning:[ ]message[ ].+[ ]delayed[ ]+
+        |Delivery[ ]Status[ ]Notification
+        |Mail[ ]failure
+        |Message[ ]frozen
+        |error[(]s[)][ ]in[ ]forwarding[ ]or[ ]filtering
+        )
+    }x,
     'message-id'=> qr/\A[<]\w+[-]\w+[-]\w+[@].*mail[.]ru[>]\z/,
     # Message-Id: <E1P1YNN-0003AD-Ga@*.mail.ru>
 };
@@ -220,9 +228,6 @@ sub scan {
     require Sisimai::SMTP::Status;
 
     for my $e ( @$dscontents ) {
-        # Set default values if each value is empty.
-        $e->{'lhost'} ||= $localhost0;
-
         if( exists $e->{'alterrors'} && length $e->{'alterrors'} ) {
             # Copy alternative error message
             $e->{'diagnosis'} ||= $e->{'alterrors'};
@@ -235,7 +240,7 @@ sub scan {
         $e->{'diagnosis'} =  Sisimai::String->sweep( $e->{'diagnosis'} );
         $e->{'diagnosis'} =~ s{\b__.+\z}{};
 
-        if( ! $e->{'rhost'} ) {
+        unless( $e->{'rhost'} ) {
             # Get the remote host name
             if( $e->{'diagnosis'} =~ m/host[ \t]+([^ \t]+)[ \t]\[.+\]:[ \t]/ ) {
                 # host neko.example.jp [192.0.2.222]: 550 5.1.1 <kijitora@example.jp>... User Unknown
@@ -245,13 +250,14 @@ sub scan {
             unless( $e->{'rhost'} ) {
                 if( scalar @{ $mhead->{'received'} } ) {
                     # Get localhost and remote host name from Received header.
-                    my $r = $mhead->{'received'};
-                    $e->{'rhost'} = pop @{ Sisimai::RFC5322->received( $r->[-1] ) };
+                    my $r0 = $mhead->{'received'};
+                    $e->{'rhost'} = pop @{ Sisimai::RFC5322->received( $r0->[-1] ) };
                 }
             }
         }
+        $e->{'lhost'} ||= $localhost0;
 
-        if( ! $e->{'command'} ) {
+        unless( $e->{'command'} ) {
             # Get the SMTP command name for the session
             SMTP: for my $r ( @$ReCommand ) {
                 # Verify each regular expression of SMTP commands
@@ -271,7 +277,6 @@ sub scan {
                     $e->{'reason'} = 'blocked';
 
                 } else {
-
                     SESSION: for my $r ( keys %$ReFailure ) {
                         # Verify each regular expression of session errors
                         next unless $e->{'diagnosis'} =~ $ReFailure->{ $r };
@@ -335,7 +340,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
