@@ -15,9 +15,7 @@ my $Re1 = {
 };
 
 my $ReFailure = {
-    'hostunknown' => qr{
-        Host[ ]or[ ]domain[ ]name[ ]not[ ]found
-    }x,
+    'hostunknown' => qr/Host[ ]or[ ]domain[ ]name[ ]not[ ]found/,
 };
 
 my $Indicators = __PACKAGE__->INDICATORS;
@@ -58,10 +56,6 @@ sub scan {
     my $mbody = shift // return undef;
 
     return undef unless $mhead->{'x-aol-ip'};
-    if( 0 ) {
-        return undef unless $mhead->{'subject'} =~ $Re0->{'subject'};
-        return undef unless $mhead->{'from'}    =~ $Re0->{'from'};
-    }
 
     my $dscontents = []; push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
     my @hasdivided = split( "\n", $$mbody );
@@ -179,7 +173,7 @@ sub scan {
                 if( $e =~ m/\A[Rr]eporting-MTA:[ ]*(?:DNS|dns);[ ]*(.+)\z/ ) {
                     # Reporting-MTA: dns; mx.example.jp
                     next if length $connheader->{'lhost'};
-                    $connheader->{'lhost'} = $1;
+                    $connheader->{'lhost'} = lc $1;
                     $connvalues++;
 
                 } elsif( $e =~ m/\A[Aa]rrival-[Dd]ate:[ ]*(.+)\z/ ) {
@@ -205,9 +199,9 @@ sub scan {
 
         if( scalar @{ $mhead->{'received'} } ) {
             # Get localhost and remote host name from Received header.
-            my $r = $mhead->{'received'};
-            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r->[0] ) };
-            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r->[-1] ) };
+            my $r0 = $mhead->{'received'};
+            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r0->[0] ) };
+            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r0->[-1] ) };
         }
         $e->{'diagnosis'} =~ s{\\n}{ }g;
         $e->{'diagnosis'} =  Sisimai::String->sweep( $e->{'diagnosis'} );
@@ -221,8 +215,8 @@ sub scan {
 
         if( length( $e->{'status'} ) == 0 || $e->{'status'} =~ m/\A\d[.]0[.]0\z/ ) {
             # There is no value of Status header or the value is 5.0.0, 4.0.0
-            my $r = Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
-            $e->{'status'} = $r if length $r;
+            my $pseudostatus = Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
+            $e->{'status'} = $pseudostatus if length $pseudostatus;
         }
 
         $e->{'spec'} ||= 'SMTP';
@@ -274,7 +268,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
