@@ -27,9 +27,12 @@ my $Indicators = __PACKAGE__->INDICATORS;
 my $LongFields = Sisimai::RFC5322->LONGFIELDS;
 my $RFC822Head = Sisimai::RFC5322->HEADERFIELDS;
 
-sub description { 'AmazonSES(Receiving): http://aws.amazon.com/ses/' };
+sub description { 'Amazon SES(Receiving): http://aws.amazon.com/ses/' };
 sub smtpagent   { 'US::ReceivingSES' }
-sub headerlist  { return [ 'X-SES-Outgoing' ] } # 'Feedback-ID'
+
+# X-SES-Outgoing: 2015.10.01-54.240.27.7
+# Feedback-ID: 1.us-west-2.HX6/J9OVlHTadQhEu1+wdF9DBj6n6Pa9sW5Y/0pSOi8=:AmazonSES
+sub headerlist  { return [ 'X-SES-Outgoing' ] }
 sub pattern     { return $Re0 }
 
 sub scan {
@@ -50,11 +53,6 @@ sub scan {
     my $mbody = shift // return undef;
 
     return undef unless $mhead->{'x-ses-outgoing'};
-    if( 0 ) {
-        # return undef unless $mhead->{'feedback-id'};
-        return undef unless $mhead->{'subject'} =~ $Re0->{'subject'};
-        return undef unless grep { $_ =~ $Re0->{'received'} } @{ $mhead->{'received'} };
-    }
 
     my $dscontents = []; push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
     my @hasdivided = split( "\n", $$mbody );
@@ -66,7 +64,7 @@ sub scan {
     my $connvalues = 0;     # (Integer) Flag, 1 if all the value of $connheader have been set
     my $connheader = {
         'date'  => '',      # The value of Arrival-Date header
-        'rhost' => '',      # The value of Reporting-MTA header
+        'lhost' => '',      # The value of Reporting-MTA header
     };
 
     my $v = undef;
@@ -158,7 +156,6 @@ sub scan {
                     $v->{'date'} = $1;
 
                 } else {
-
                     if( $e =~ m/\A[Dd]iagnostic-[Cc]ode:[ ]*(.+?);[ ]*(.+)\z/ ) {
                         # Diagnostic-Code: SMTP; 550 5.1.1 <kijitora@example.jp>... User Unknown
                         $v->{'spec'} = uc $1;
@@ -180,8 +177,8 @@ sub scan {
                 # Reporting-MTA: dns; inbound-smtp.us-west-2.amazonaws.com
                 if( $e =~ m/\A[Rr]eporting-MTA:[ ]*(?:DNS|dns);[ ]*(.+)\z/ ) {
                     # Reporting-MTA: dns; mx.example.jp
-                    next if length $connheader->{'rhost'};
-                    $connheader->{'rhost'} = $1;
+                    next if length $connheader->{'lhost'};
+                    $connheader->{'lhost'} = lc $1;
                     $connvalues++;
 
                 } elsif( $e =~ m/\A[Aa]rrival-[Dd]ate:[ ]*(.+)\z/ ) {
@@ -207,25 +204,25 @@ sub scan {
 
         if( scalar @{ $mhead->{'received'} } ) {
             # Get localhost and remote host name from Received header.
-            my $r = $mhead->{'received'};
-            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r->[0] ) };
-            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r->[-1] ) };
+            my $r0 = $mhead->{'received'};
+            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r0->[0] ) };
+            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r0->[-1] ) };
         }
         $e->{'diagnosis'} =~ s{\\n}{ }g;
         $e->{'diagnosis'} =  Sisimai::String->sweep( $e->{'diagnosis'} );
 
         if( $e->{'status'} =~ m/\A[45][.][01][.]0\z/ ) {
             # Get other D.S.N. value from the error message
-            my $r = '';
-            my $x = $e->{'diagnosis'};
+            my $pseudostatus = '';
+            my $errormessage = $e->{'diagnosis'};
 
             if( $e->{'diagnosis'} =~ m/["'](\d[.]\d[.]\d.+)['"]/ ) {
                 # 5.1.0 - Unknown address error 550-'5.7.1 ...
-                $x = $1;
+                $errormessage = $1;
             }
 
-            $r = Sisimai::SMTP::Status->find( $x );
-            $e->{'status'} = $r if length $r;
+            $pseudostatus = Sisimai::SMTP::Status->find( $errormessage );
+            $e->{'status'} = $pseudostatus if length $pseudostatus;
         }
 
         SESSION: for my $r ( keys %$ReFailure ) {
@@ -286,7 +283,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2015 azumakuniyuki, All rights reserved.
+Copyright (C) 2015-2016 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
