@@ -23,11 +23,7 @@ sub description { 'Verizon Wireless: http://www.verizonwireless.com' }
 sub smtpagent   { 'US::Verizon' }
 sub pattern     { 
     return {
-        'from'    => qr{(?:
-                         \Apost_master[@]vtext[.]com
-                        |[<]?sysadmin[@].+[.]vzwpix[.]com[>]?
-                        )\z
-                     }x,
+        'from' => qr/[<]?(?:\Apost_master[@]vtext|sysadmin[@].+[.]vzwpix)[.]com[>]?\z/,
         'subject' => $Re0->{'vzwpix.com'}->{'subject'},
     };
 }
@@ -48,20 +44,20 @@ sub scan {
     my $class = shift;
     my $mhead = shift // return undef;
     my $mbody = shift // return undef;
-    my $vtext = undef;
+    my $match = -1;
 
     while(1) {
         # Check the value of "From" header
         last unless grep { $_ =~ $Re0->{'received'} } @{ $mhead->{'received'} };
-        $vtext = 1 if $mhead->{'from'} =~ $Re0->{'vtext.com'}->{'from'};
-        $vtext = 0 if $mhead->{'from'} =~ $Re0->{'vzwpix.com'}->{'from'};
+        $match = 1 if $mhead->{'from'} =~ $Re0->{'vtext.com'}->{'from'};
+        $match = 0 if $mhead->{'from'} =~ $Re0->{'vzwpix.com'}->{'from'};
         last;
     }
-    return undef unless defined $vtext;
+    return undef if $match < 0;
 
     require Sisimai::MIME;
+    require Sisimai::String;
     require Sisimai::Address;
-
     my $dscontents = []; push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
     my @hasdivided = split( "\n", $$mbody );
     my $rfc822next = { 'from' => 0, 'to' => 0, 'subject' => 0 };
@@ -77,14 +73,13 @@ sub scan {
     my $boundary00 = '';    # (String) Boundary string
     my $v = undef;
 
-    if( $vtext == 1 ) {
+    if( $match == 1 ) {
         # vtext.com
         $Re1 = {
             'begin'  => qr/\AError:[ \t]/,
             'rfc822' => qr/\A__BOUNDARY_STRING_HERE__\z/,
             'endof'  => qr/\A__END_OF_EMAIL_MESSAGE__\z/,
         };
-
         $ReFailure = {
             'userunknown' => qr{
                 # The attempted recipient address does not exist.
@@ -94,7 +89,10 @@ sub scan {
 
         $rfc822next = { 'from' => 0, 'to' => 0, 'subject' => 0 };
         $boundary00 = Sisimai::MIME->boundary( $mhead->{'content-type'} );
-        $Re1->{'rfc822'} = qr/\A[-]{2}$boundary00[-]{2}\z/ if length $boundary00;
+        if( length $boundary00 ) {
+            # Convert to regular expression
+            $Re1->{'rfc822'} = Sisimai::String->to_regexp( '--'.$boundary00.'--' ); 
+        }
 
         for my $e ( @hasdivided ) {
             # Read each line between $Re0->{'begin'} and $Re0->{'rfc822'}.
@@ -141,20 +139,19 @@ sub scan {
                 next unless $readcursor & $Indicators->{'deliverystatus'};
                 next unless length $e;
 
+                # Message details:
+                #   Subject: Test message
+                #   Sent date: Wed Jun 12 02:21:53 GMT 2013
+                #   MAIL FROM: *******@hg.example.com
+                #   RCPT TO: *****@vtext.com
                 $v = $dscontents->[ -1 ];
 
                 if( $e =~ m/\A[ \t]+RCPT TO: (.*)\z/ ) {
-                    # Message details:
-                    #   Subject: Test message
-                    #   Sent date: Wed Jun 12 02:21:53 GMT 2013
-                    #   MAIL FROM: *******@hg.example.com
-                    #   RCPT TO: *****@vtext.com
                     if( length $v->{'recipient'} ) {
                         # There are multiple recipient addresses in the message body.
                         push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
                         $v = $dscontents->[ -1 ];
                     }
-
                     $v->{'recipient'} = $1;
                     $recipients++;
                     next;
@@ -168,11 +165,8 @@ sub scan {
                     $subjecttxt ||= $1;
 
                 } else {
-
-                    if( $e =~ m/\A(\d{3})[ \t][-][ \t](.*)\z/ ) {
-                        # 550 - Requested action not taken: no such user here
-                        $v->{'diagnosis'} = $e;
-                    }
+                    # 550 - Requested action not taken: no such user here
+                    $v->{'diagnosis'} = $e if $e =~ m/\A(\d{3})[ \t][-][ \t](.*)\z/;
                 }
             } # End of if: rfc822
         }
@@ -183,7 +177,6 @@ sub scan {
             'rfc822' => qr/\A__BOUNDARY_STRING_HERE__\z/,
             'endof'  => qr/\A__END_OF_EMAIL_MESSAGE__\z/,
         };
-
         $ReFailure = {
             'userunknown' => qr{
                 No[ ]valid[ ]recipients[ ]for[ ]this[ ]MM
@@ -192,7 +185,10 @@ sub scan {
 
         $rfc822next = { 'from' => 0, 'to' => 0, 'subject' => 0 };
         $boundary00 = Sisimai::MIME->boundary( $mhead->{'content-type'} );
-        $Re1->{'rfc822'} = qr/\A[-]{2}$boundary00[-]{2}\z/ if length $boundary00;
+        if( length $boundary00 ) {
+            # Convert to regular expression
+            $Re1->{'rfc822'} = Sisimai::String->to_regexp( '--'.$boundary00.'--' ); 
+        }
 
         for my $e ( @hasdivided ) {
             # Read each line between $Re0->{'begin'} and $Re0->{'rfc822'}.
@@ -239,20 +235,19 @@ sub scan {
                 next unless $readcursor & $Indicators->{'deliverystatus'};
                 next unless length $e;
 
+                # Original Message:
+                # From: kijitora <kijitora@example.jp>
+                # To: 0000000000@vzwpix.com
+                # Subject: test for bounce
+                # Date:  Wed, 20 Jun 2013 10:29:52 +0000
                 $v = $dscontents->[ -1 ];
 
                 if( $e =~ m/\ATo:[ \t]+(.*)\z/ ) {
-                    # Original Message:
-                    # From: kijitora <kijitora@example.jp>
-                    # To: 0000000000@vzwpix.com
-                    # Subject: test for bounce
-                    # Date:  Wed, 20 Jun 2013 10:29:52 +0000
                     if( length $v->{'recipient'} ) {
                         # There are multiple recipient addresses in the message body.
                         push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
                         $v = $dscontents->[ -1 ];
                     }
-
                     $v->{'recipient'} = Sisimai::Address->s3s4( $1 );
                     $recipients++;
                     next;
@@ -266,12 +261,9 @@ sub scan {
                     $subjecttxt ||= $1;
 
                 } else {
-
-                    if( $e =~ m/\AError:[ \t]+(.+)\z/ ) {
-                        # Message could not be delivered to mobile.
-                        # Error: No valid recipients for this MM
-                        $v->{'diagnosis'} = $e;
-                    }
+                    # Message could not be delivered to mobile.
+                    # Error: No valid recipients for this MM
+                    $v->{'diagnosis'} = $e if $e =~ m/\AError:[ \t]+(.+)\z/;
                 }
             } # End of if: rfc822
         }
@@ -282,15 +274,14 @@ sub scan {
     $rfc822part .= sprintf( "From: %s\n", $senderaddr ) unless $rfc822part =~ m/\bFrom: /;
     $rfc822part .= sprintf( "Subject: %s\n", $subjecttxt ) unless $rfc822part =~ m/\bSubject: /;
 
-    require Sisimai::String;
     require Sisimai::SMTP::Status;
 
     for my $e ( @$dscontents ) {
         if( scalar @{ $mhead->{'received'} } ) {
             # Get localhost and remote host name from Received header.
-            my $r = $mhead->{'received'};
-            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r->[0] ) };
-            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r->[-1] ) };
+            my $r0 = $mhead->{'received'};
+            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r0->[0] ) };
+            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r0->[-1] ) };
         }
         $e->{'diagnosis'} = Sisimai::String->sweep( $e->{'diagnosis'} );
 
@@ -353,7 +344,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
