@@ -7,10 +7,10 @@ use warnings;
 my $Re0 = {
     'from'     => qr/mailer-daemon[@]mail[.]zoho[.]com\z/,
     'subject'  => qr{\A(?:
-                     Undelivered[ ]Mail[ ]Returned[ ]to[ ]Sender
-                    |Mail[ ]Delivery[ ]Status[ ]Notification
-                    )
-                  }x,
+         Undelivered[ ]Mail[ ]Returned[ ]to[ ]Sender
+        |Mail[ ]Delivery[ ]Status[ ]Notification
+        )
+    }x,
     'x-mailer' => qr/\AZoho Mail\z/,
 };
 my $Re1 = {
@@ -54,12 +54,6 @@ sub scan {
     my $mbody = shift // return undef;
 
     return undef unless $mhead->{'x-zohomail'};
-    if( 0 ) {
-        return undef unless $mhead->{'from'}     =~ $Re0->{'from'};
-        return undef unless $mhead->{'subject'}  =~ $Re0->{'subject'};
-        return undef unless $mhead->{'x-mailer'} =~ $Re0->{'x-mailer'};
-    }
-    require Sisimai::RFC5322;
 
     my $dscontents = []; push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
     my @hasdivided = split( "\n", $$mbody );
@@ -137,14 +131,14 @@ sub scan {
                     $v = $dscontents->[ -1 ];
                 }
                 $v->{'recipient'} = $1;
-                $recipients++;
+                $v->{'diagnosis'} = $2;
 
-                $v->{'diagnosis'} =  $2;
                 if( $v->{'diagnosis'} =~ m/=\z/ ) {
                     # Quoted printable
                     $v->{'diagnosis'} =~ s/=\z//;
                     $qprintable = 1;
                 }
+                $recipients++;
 
             } elsif( $e =~ m/\A\[Status: .+[<]([^ ]+[@][^ ]+)[>],/ ) {
                 # Expired
@@ -155,9 +149,8 @@ sub scan {
                     $v = $dscontents->[ -1 ];
                 }
                 $v->{'recipient'} = $1;
-                $recipients++;
-
                 $v->{'diagnosis'} = $e;
+                $recipients++;
 
             } else {
                 # Continued line
@@ -174,9 +167,9 @@ sub scan {
     for my $e ( @$dscontents ) {
         if( scalar @{ $mhead->{'received'} } ) {
             # Get localhost and remote host name from Received header.
-            my $r = $mhead->{'received'};
-            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r->[0] ) };
-            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r->[-1] ) };
+            my $r0 = $mhead->{'received'};
+            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r0->[0] ) };
+            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r0->[-1] ) };
         }
         $e->{'diagnosis'} =~ s{\\n}{ }g;
         $e->{'diagnosis'} =  Sisimai::String->sweep( $e->{'diagnosis'} );
@@ -202,7 +195,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::MSP::US::Zoho - bounce mail parser class for C<Zoho! MAIL>.
+Sisimai::MSP::US::Zoho - bounce mail parser class for C<Zoho Mail>.
 
 =head1 SYNOPSIS
 
@@ -238,7 +231,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
