@@ -4,27 +4,57 @@ use strict;
 use warnings;
 use Sisimai::RFC5322;
 
-sub SMTPCOMMAND {
-    # Detector for SMTP commands in a bounce mail message
-    # @private
-    # @return   [Hash] SMTP command regular expressions
-    return {
-        'helo' => qr/\b(?:HELO|EHLO)\b/,
-        'mail' => qr/\bMAIL F(?:ROM|rom)\b/,
-        'rcpt' => qr/\bRCPT T[Oo]\b/,
-        'data' => qr/\bDATA\b/,
-    };
-}
 sub EOM {
     # End of email message as a sentinel for parsing bounce messages
+    # @return   [String] Fixed length string like a constant
     # @private
     # @deprecated
-    # @return   [String] Fixed length string like a constant
-    my $class = shift;
-    my $klass = 'Sisimai::String';
-    warn sprintf( "***warning: %s->EOM deprecated method. Use %s->EOM() instead.", $class, $klass );
-    return '__END_OF_EMAIL_MESSAGE__';
+    require Sisimai::String;
+    warn sprintf(" ***warning: Obsoleted method, use Sisimai::String->EOM() instead.");
+    return Sisimai::String->EOM;
 }
+sub SMTPCOMMAND {
+    # Detector for SMTP commands in a bounce mail message
+    # @return   [Hash] SMTP command regular expressions
+    # @private
+    # @deprecated
+    require Sisimai::SMTP;
+    warn sprintf(" ***warning: Obsoleted method, use Sisimai::SMTP->command() instead.");
+    return Sisimai::SMTP->command;
+}
+
+sub LONGFIELDS {
+    # Fields that might be long
+    # @return   [Hash] Long filed(email header) list
+    # @private
+    # @deprecated
+    warn sprintf(" ***warning: Obsoleted method, use Sisimai::RFC5322->LONGFIELDS() instead.");
+    return Sisimai::RFC5322->LONGFIELDS;
+}
+
+sub RFC822HEADERS { 
+    # Grouped RFC822 headers
+    # @param    [String] group  RFC822 Header group name
+    # @return   [Array,Hash]    RFC822 Header list
+    # @private
+    # @deprecated
+    warn sprintf(" ***warning: Obsoleted method, use Sisimai::RFC5322->HEADERFIELDS() instead.");
+    my $class = shift;
+    my $group = shift // return [ keys %{ Sisimai::RFC5322->HEADERFIELDS } ];
+    return Sisimai::RFC5322->HEADERFIELDS( $group );
+}
+
+sub INDICATORS {
+    # Flags for position variable for
+    # @private
+    # @return   [Hash] Position flag data
+    # @since    v4.13.0
+    return {
+        'deliverystatus' => ( 1 << 1 ),
+        'message-rfc822' => ( 1 << 2 ),
+    };
+}
+
 sub DELIVERYSTATUS {
     # Data structure for parsed bounce messages
     # @private
@@ -43,38 +73,7 @@ sub DELIVERYSTATUS {
         'diagnosis'    => '',   # The value of Diagnostic-Code header
         'recipient'    => '',   # The value of Final-Recipient header
         'softbounce'   => '',   # Soft bounce or not
-        'feedbacktype' => '',   # FeedBack Type
-    };
-}
-
-sub LONGFIELDS {
-    # Fields that might be long
-    # @private
-    # @deprecated
-    # @return   [Hash] Long filed(email header) list
-    return [ keys %{ Sisimai::RFC5322->LONGFIELDS } ];
-}
-
-sub RFC822HEADERS { 
-    # Grouped RFC822 headers
-    # @private
-    # @deprecated
-    # @param    [String] group  RFC822 Header group name
-    # @return   [Array,Hash]    RFC822 Header list
-    my $class = shift;
-    my $group = shift // return [ keys %{ Sisimai::RFC5322->HEADERFIELDS } ];
-    my $index = Sisimai::RFC5322->HEADERFIELDS( $group );
-    return $index;
-}
-
-sub INDICATORS {
-    # Flags for position variable for
-    # @private
-    # @return   [Hash] Position flag data
-    # @since    v4.13.0
-    return {
-        'deliverystatus' => ( 1 << 1 ),
-        'message-rfc822' => ( 1 << 2 ),
+        'feedbacktype' => '',   # Feedback Type
     };
 }
 
@@ -156,8 +155,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
