@@ -21,7 +21,6 @@ my $RFC822Head = Sisimai::RFC5322->HEADERFIELDS;
 
 sub description { 'Trustwave Secure Email Gateway' }
 sub smtpagent   { 'MailMarshalSMTP' }
-sub headerlist  { return [ 'X-Mailer' ] }
 sub pattern     { return $Re0 }
 
 sub scan {
@@ -42,8 +41,9 @@ sub scan {
     my $mbody = shift // return undef;
 
     return undef unless $mhead->{'subject'} =~ $Re0->{'subject'};
-    require Sisimai::MIME;
 
+    require Sisimai::MIME;
+    require Sisimai::String;
     my $dscontents = []; push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
     my @hasdivided = split( "\n", $$mbody );
     my $rfc822next = { 'from' => 0, 'to' => 0, 'subject' => 0 };
@@ -56,8 +56,13 @@ sub scan {
     my $v = undef;
 
     $boundary00 = Sisimai::MIME->boundary( $mhead->{'content-type'} );
-    $Re1->{'rfc822'} = qr/\A[-]{2}$boundary00[-]{2}\z/ if length $boundary00;
-    $Re1->{'rfc822'} = qr/\A[ \t]*[+]+[ \t]*\z/ unless $Re1->{'rfc822'};
+    if( length $boundary00 ) {
+        # Convert to regular expression
+        $Re1->{'rfc822'} = Sisimai::String->to_regexp( '--'.$boundary00.'--' );
+
+    } else {
+        $Re1->{'rfc822'} = qr/\A[ \t]*[+]+[ \t]*\z/;
+    }
 
     for my $e ( @hasdivided ) {
         # Read each line between $Re1->{'begin'} and $Re1->{'rfc822'}.
@@ -167,7 +172,6 @@ sub scan {
     }
 
     return undef unless $recipients;
-    require Sisimai::String;
     require Sisimai::SMTP::Status;
 
     for my $e ( @$dscontents ) {
@@ -175,9 +179,9 @@ sub scan {
 
         if( scalar @{ $mhead->{'received'} } ) {
             # Get localhost and remote host name from Received header.
-            my $r = $mhead->{'received'};
-            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r->[0] ) };
-            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r->[-1] ) };
+            my $r0 = $mhead->{'received'};
+            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r0->[0] ) };
+            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r0->[-1] ) };
         }
         $e->{'diagnosis'} = Sisimai::String->sweep( $e->{'diagnosis'} );
         $e->{'status'}    = Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
@@ -233,7 +237,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
