@@ -97,7 +97,7 @@ sub scan {
 
         if( $readcursor & $Indicators->{'message-rfc822'} ) {
             # After "message/rfc822"
-            if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
+            if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.*\z/ ) {
                 # Get required headers only
                 my $lhs = lc $1;
                 $previousfn = '';
@@ -187,7 +187,6 @@ sub scan {
                         $e = 'Diagnostic-Code: '.$e;
                     }
                 }
-
             } else {
                 # If you do so, please include this problem report. You can
                 # delete your own text from the attached returned message.
@@ -210,7 +209,7 @@ sub scan {
                     if( $e =~ m/\A[Rr]eporting-MTA:[ ]*(?:DNS|dns);[ ]*(.+)\z/ ) {
                         # Reporting-MTA: dns; mx.example.jp
                         next if $connheader->{'lhost'};
-                        $connheader->{'lhost'} = $1;
+                        $connheader->{'lhost'} = lc $1;
                         $connvalues++;
 
                     } elsif( $e =~ m/\A[Aa]rrival-[Dd]ate:[ ]*(.+)\z/ ) {
@@ -288,9 +287,9 @@ sub scan {
 
         if( scalar @{ $mhead->{'received'} } ) {
             # Get localhost and remote host name from Received header.
-            my $r = $mhead->{'received'};
-            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r->[0] ) };
-            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r->[-1] ) };
+            my $r0 = $mhead->{'received'};
+            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r0->[0] ) };
+            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r0->[-1] ) };
         }
 
         if( length( $e->{'status'} ) == 0 || $e->{'status'} =~ m/\A\d[.]0[.]0\z/ ) {
@@ -298,7 +297,6 @@ sub scan {
             my $r = Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
             $e->{'status'} = $r if length $r;
         }
-        # $e->{'softbounce'} = Sisimai::SMTP->is_softbounce( $e->{'status'} );
     }
     return { 'ds' => $dscontents, 'rfc822' => $rfc822part };
 }
@@ -346,7 +344,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
