@@ -1,6 +1,7 @@
 package Sisimai::RFC5321;
 use strict;
 use warnings;
+use Sisimai::SMTP::Reply;
 
 # http://www.ietf.org/rfc/rfc5321.txt
 #   4.2.1.  Reply Code Severities and Theory
@@ -63,13 +64,11 @@ sub getrc {
     # @param    [String] rtext  String including SMTP Reply Code like 550
     # @return   [String]        SMTP Reply Code or empty if the first argument
     #                           did not include SMTP Reply Code value
+    # @deprecated use Sisimai::SMTP::Reply->find() method instead
     my $class = shift;
-    my $rtext = shift || return '';
-    my $rcode = '';
 
-    return ''   if $rtext =~ m/X-Unix;/i;
-    $rcode = $1 if $rtext =~ m/\b([45][0-5][0-9])\b/;
-    return $rcode;
+    warn sprintf(" ***warning: Obsoleted method, use Sisimai::SMTP::Reply->find() instead.");
+    return Sisimai::SMTP::Reply->find(shift);
 }
 
 1;
@@ -79,7 +78,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::RFC5321 - SMTP Reply code related class
+Sisimai::RFC5321 - SMTP Reply code related class (Obsolete)
 
 =head1 SYNOPSIS
 
@@ -91,11 +90,14 @@ Sisimai::RFC5321 - SMTP Reply code related class
 Sisimai::RFC5321 is utilities for getting SMTP Reply Code value from error 
 message text.
 
+This class has been obsoleted from Sisimai 4.14.0, use Sisimai::SMPT::Reply
+module instead.
+
 =head1 CLASS METHODS
 
 =head2 C<B<getrc( I<String> )>>
 
-C<getdsn()> returns a SMTP Reply Code value.
+C<getrc()> returns a SMTP Reply Code value.
 
     print Sisimai::RFC5321->getrc('5.0.0');                   # ''
     print Sisimai::RFC5321->getrc('550 5.1.1 User unknown');  # 550
@@ -106,8 +108,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
