@@ -67,7 +67,7 @@ sub HEADERFIELDS {
 sub LONGFIELDS {
     # Fields that might be long
     # @return   [Hash] Long filed(email header) list
-    return { 'to' => 1, 'from' => 1, 'subject' => 1 };
+    return { 'to' => 1, 'from' => 1, 'subject' => 1, 'message-id' => 1 };
 }
 
 sub is_emailaddress {
@@ -273,7 +273,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
