@@ -6,12 +6,12 @@ use warnings;
 sub text  { 'norelaying' }
 sub match {
     # Try to match that the given text and regular expressions
-    # @param    [String] argvs  String to be matched with regular expressions
+    # @param    [String] argv1  String to be matched with regular expressions
     # @return   [Integer]       0: Did not match
     #                           1: Matched
     # @since v4.0.0
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argv1 = shift // return undef;
     my $regex = qr{(?> 
          Insecure[ ]Mail[ ]Relay
         |mail[ ]server[ ]requires[ ]authentication[ ]when[ ]attempting[ ]to[ ]
@@ -28,7 +28,7 @@ sub match {
         )
     }ix;
 
-    return 1 if $argvs =~ $regex;
+    return 1 if $argv1 =~ $regex;
     return 0;
 }
 
@@ -44,12 +44,11 @@ sub true {
 
     return undef unless ref $argvs eq 'Sisimai::Data';
     my $currreason = $argvs->reason // '';
-    my $reasontext = __PACKAGE__->text;
+    my $reexcludes = qr/\A(?:securityerror|systemerror|undefined)\z/;
 
     if( $currreason ) {
         # Do not overwrite the reason
-        my $rxnr = qr/\A(?:securityerror|systemerror|undefined)\z/;
-        return 0 if $currreason =~ $rxnr;
+        return 0 if $currreason =~ $reexcludes;
 
     } else {
         # Check the value of Diagnosic-Code: header with patterns
@@ -109,8 +108,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
