@@ -26,10 +26,12 @@ sub list {
             MSP/RU/Yandex.pm
             MSP/UK/MessageLabs.pm
             MSP/US/AmazonSES.pm
+            MSP/US/AmazonWorkMail.pm
             MSP/US/Aol.pm
             MSP/US/Bigfoot.pm
             MSP/US/Facebook.pm
             MSP/US/Google.pm
+            MSP/US/Office365.pm
             MSP/US/Outlook.pm
             MSP/US/ReceivingSES.pm
             MSP/US/SendGrid.pm
